@@ -178,7 +178,10 @@ def launch_behavex():
         customized_json = get_param('customized_json')
         print("customized_json")
         print(customized_json)
-        if bool(customized_json) is not True and str(customized_json) != 'True':
+        print(bool(customized_json) is True)
+        print(str(customized_json) == 'True')
+        if bool(customized_json) is True or str(customized_json) == 'True':
+            print("use merged json data: %s\\report_data.json" % os.environ.get('FEATURES_PATH'))
             with open("%s\\report_data.json" % os.environ.get('FEATURES_PATH'), 'r') as f:
                 json_reports = json.load(f)
 
